# Image Preparation

The Image Preparation group allows to perform basic operation before the image is displayed.

- Background image: subtract background from a file or one image from an image source
- Mask image: mask plotted image with respect to a file.
  Convention of zero mask pixels can be set in the configuration, by default none-zero masks pixel to zero.
- Mask values above: mask image pixels which have intensity above the given value
- Transformation: all 8 possible. Whether axes are changing with transformations or not can be set in the configuration.

Background image and mask image can be loaded from the file formats supported by fabio or a NeXus file.